==> ask-cli-1.6.0.tgz: package/test/unit/dialog/response-parser-test.js <==
'use strict';

const chai = require('chai');
const expect = chai.expect;
const sinon = require('sinon');
const simulateDialogResponseParser = require('../../../lib/dialog/response-parser');

describe('dialog response parser testing', () => {
    describe('# response parser testing', () => {
        let sandbox;
        let testObject;

        beforeEach(() => {
            sandbox = sinon.sandbox.create();
        });
        afterEach(() => {
            sandbox.restore();
        });

        it ('| return jsonInput when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocationRequest": {
                            "body": {
                                "version": "1.0",
                                "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                }                               
                            }
                        }
                    }
                }
            };
            const currentJson = simulateDialogResponseParser.getJsonInput(testObject);
            const actualJson = {
                                "version": "1.0",
                                "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                }       
                            }
            expect(JSON.stringify(currentJson)).equal(JSON.stringify(actualJson));
        });

        it ('| return empty object when input failed response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocationRequest": null
                    }
                }
            };

            const currentJson = simulateDialogResponseParser.getJsonInput(testObject);

            expect(JSON.stringify(currentJson)).equal(JSON.stringify({}));
        });

        it ('| return jsonOnput when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocationResponse": {
                            "body": {
                                "version": "1.0",
                                "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                }                               
                            }
                        }
                    }
                }
            };
            const currentJson = simulateDialogResponseParser.getJsonOutput(testObject);
            const actualJson = {
                                "body": {
                                    "version": "1.0",
                                    "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                    }   
                                }           
                            }
            expect(JSON.stringify(currentJson)).equal(JSON.stringify(actualJson));
        });

        it ('| return empty object when input failed response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocationResponse": null
                    }
                }
            };
    
            const currentJson = simulateDialogResponseParser.getJsonOutput(testObject);
    
            expect(JSON.stringify(currentJson)).equal(JSON.stringify({}));
        });

        it ('| return shouldEndSession value when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocationResponse": {
                            "body": {
                                "version": "1.0",
                                "response": {
                                    "outputSpeech": {
                                    },
                                    "shouldEndSession": true
                                }                          
                            }
                        }
                    }
                }
            };
            const shouldEndSession = simulateDialogResponseParser.isSkillResponseSessionEnd(testObject);
           
            expect(shouldEndSession).equal(true);
        });
    });
});

==> ask-cli-1.7.12.tgz: package/test/unit/dialog/response-parser-test.js <==
'use strict';

const chai = require('chai');
const expect = chai.expect;
const sinon = require('sinon');
const simulateDialogResponseParser = require('../../../lib/dialog/response-parser');

describe('dialog response parser testing', () => {
    describe('# response parser testing', () => {
        let sandbox;
        let testObject;

        beforeEach(() => {
            sandbox = sinon.sandbox.create();
        });
        afterEach(() => {
            sandbox.restore();
        });

        it ('| return jsonInput when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocations":[{
                            "invocationRequest":{
                            "body": {
                                "version": "1.0",
                                "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                }                               
                            }
                        }
                        }]
                    }
                }
            };
            const currentJson = simulateDialogResponseParser.getJsonInputAndOutputs(testObject);
            const actualJson = {
                                "version": "1.0",
                                "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                }       
                            }
            expect(JSON.stringify(currentJson[0]['jsonInput'])).equal(JSON.stringify(actualJson));
        });

        it ('| return empty object when input failed response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocations":[]
                    }
                }
            };

            const currentJson = simulateDialogResponseParser.getJsonInputAndOutputs(testObject);

            expect(JSON.stringify(currentJson)).equal(JSON.stringify([]));
        });

        it ('| return jsonOnput when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocations":[{
                            "invocationResponse":{
                                "body": {
                                    "version": "1.0",
                                    "session": {
                                        "new": false,
                                        "sessionId": "amzn1",
                                        "application": {
                                        "applicationId": "amzn1"
                                        },
                                        "attributes": {} 
                                    }                               
                                }
                            }
                        }]
                    }
                }
            };
            const currentJson = simulateDialogResponseParser.getJsonInputAndOutputs(testObject);
            const actualJson = {
                                "body": {
                                    "version": "1.0",
                                    "session": {
                                    "new": false,
                                    "sessionId": "amzn1",
                                    "application": {
                                    "applicationId": "amzn1"
                                    },
                                    "attributes": {} 
                                    }   
                                }           
                            }
            expect(JSON.stringify(currentJson[0]['jsonOutput'])).equal(JSON.stringify(actualJson));
        });

        it ('| return empty object when input failed response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocations":[]
                    }
                }
            };
    
            const currentJson = simulateDialogResponseParser.getJsonInputAndOutputs(testObject);
    
            expect(JSON.stringify(currentJson)).equal(JSON.stringify([]));
        });

        it ('| return shouldEndSession value when input successful response', () => {
            testObject = {
                "result": {
                    "skillExecutionInfo": {
                        "invocations":[{
                            "invocationResponse": {
                                "body": {
                                    "version": "1.0",
                                    "response": {
                                        "outputSpeech": {
                                        },
                                        "shouldEndSession": true
                                    }                          
                                }
                            }
                        }]
                    }
                }
            };
            const shouldEndSession = simulateDialogResponseParser.isSkillResponseSessionEnd(testObject);
           
            expect(shouldEndSession).equal(true);
        });
    });
});
